##  Introduction to the SAP LeanIX Store
The [SAP LeanIX Store![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fstore.leanix.net%2F "https://store.leanix.net/") provides access to custom reports developed by SAP LeanIX and external providers. As an admin user, you can download custom reports to your workspace and make them available to all workspace users.
You can develop your own custom reports and publish them on the SAP LeanIX Store. To learn more, see [Custom Reports](https://help.sap.com/docs/leanix/ea/custom-reports?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to build custom reports tailored to your organization's needs.").
